@@ -6,6 +6,7 @@ from copy import deepcopy
 import urllib2
 from pyff.decorators import retry
 import logging
+from pyff.utils import schema
 
 __author__ = 'leifj'
 
@@ -97,9 +98,8 @@ Find a (set of) EntityDescriptor element(s) based on the specified 'member' expr
             raise Exception,"What about %s ??" % member
 
     def lookup(self,member,xp=None):
-        print "lookup %s" % member
+        logging.debug("lookup %s" % member)
         l = self._lookup(member,xp)
-        print l
         return list(set(filter(lambda x: x is not None,l)))
 
 
@@ -119,11 +119,11 @@ Produce an EntityDescriptors set from a list of entities. Optional Name, cacheDu
             attrs['validUntil'] = validUntil
         t = etree.Element("{urn:oasis:names:tc:SAML:2.0:metadata}EntitiesDescriptor",**attrs)
         for member in entities:
-            print member
             for ent in self.lookup(member):
                 if ent is not None:
                     t.append(deepcopy(ent))
 
+        schema().assertValid(t)
         return t
 
     def keys(self):
@@ -137,12 +137,3 @@ Produce an EntityDescriptors set from a list of entities. Optional Name, cacheDu
 
     def __delitem__(self, key):
         del self.md[key]
-
-    @retry(Exception,tries=10)
-    def load_url(self,url=None,verify=None):
-        if url is not None:
-            logging.info("loading %s ..." % url)
-            request = urllib2.Request(url)
-            response = urllib2.urlopen(request)
-            # TODO figure out what to stick in md
-            self.parse_metadata(response,verify)
\ No newline at end of file
